pub struct RealmOptions {
pub use_fake_sag: Option<bool>,
pub wait_for_suspending_token: Option<bool>,
pub use_suspender: Option<bool>,
pub stuck_warning_timeout_seconds: Option<u32>,
pub reboot_on_stalled_suspend_blocker: Option<bool>,
pub long_wake_lease_timeout_seconds: Option<u32>,
pub use_fake_clock: Option<bool>,
/* private fields */
}Expand description
RealmOptions tells the RealmFactory protocol how to create the test realm.
Fields
use_fake_sag: Option<bool>Specifies whether to use a fake SAG that exposes additional protocols to set/watch real SAG power element power levels. Defaults to false.
wait_for_suspending_token: Option<bool>Specifies whether to set the fuchsia.power.WaitForSuspendingToken config
capability to true. If true, SAG will wait to receive a token through
[fuchsia.power.system/CpuElementManager.AddExectuionStateDependency].
If false, SAG will skip adding external Execution State dependencies.
Defaults to false.
use_suspender: Option<bool>Specifies whether SAG will use a suspender or not. Defaults to true.
stuck_warning_timeout_seconds: Option<u32>Specifies the timeout in seconds for the suspend/resume watchdog. Defaults to 60 seconds if not specified.
reboot_on_stalled_suspend_blocker: Option<bool>Specifies whether SAG will trigger a reboot when a suspend/resume hang is detected. Defaults to false.
long_wake_lease_timeout_seconds: Option<u32>Specifies the timeout in seconds for the long wake lease watchdog. Recommended to use default of 60 seconds in test.
use_fake_clock: Option<bool>Specifies whether to use a fake clock for SAG. Defaults to false.